import 'dart:collection';

import 'package:enge/makers/maker.dart';
import 'package:intl/intl.dart';
import 'package:path/path.dart';
import 'package:slugify/slugify.dart';
import 'package:sprintf/sprintf.dart';

class MigrationMaker extends Maker {
  String name;

  MigrationMaker(String name) {
    this.name = name;
  }

  @override
  String getTemplateFileName() {
    return 'migration_template.template';
  }

  @override
  String getTargetLocation() {
    return join('lib', 'database', 'migrations');
  }

  @override
  String getTargetFileName() {
    final fileNamePattern = '%s_%s_migration.dart';

    final now = DateTime.now();
    final formatter = DateFormat('yyyy-MM-dd HH:mm:ss');

    var timestamp = formatter.format(now);
    timestamp = timestamp.replaceAll(' ', '_');
    timestamp = timestamp.replaceAll('-', '_');
    timestamp = timestamp.replaceAll(':', '_');

    return sprintf(fileNamePattern, [timestamp, Slugify(this.name)]);
  }

  @override
  HashMap<String, String> getVariables() {
    final variables = HashMap<String, String>();
    variables['MIGRATION_NAME'] = this.name;

    return variables;
  }
}
